@@ -92,6 +92,8 @@ extern mlt_service mlt_service_producer( mlt_service self );
 extern int mlt_service_attach( mlt_service self, mlt_filter filter );
 extern int mlt_service_detach( mlt_service self, mlt_filter filter );
 extern void mlt_service_apply_filters( mlt_service self, mlt_frame frame, int index );
+extern int mlt_service_filter_count( mlt_service self );
+extern int mlt_service_move_filter( mlt_service self, int from, int to );
 extern mlt_filter mlt_service_filter( mlt_service self, int index );
 extern mlt_profile mlt_service_profile( mlt_service self );
 extern void mlt_service_set_profile( mlt_service self, mlt_profile profile );
