@@ -111,6 +111,11 @@ int Producer::seek( int position )
 	return mlt_producer_seek( get_producer( ), position );
 }
 
+int Producer::seek( const char *time )
+{
+	return mlt_producer_seek_time( get_producer( ), time );
+}
+
 int Producer::position( )
 {
 	return mlt_producer_position( get_producer( ) );
@@ -121,6 +126,11 @@ int Producer::frame( )
 	return mlt_producer_frame( get_producer( ) );
 }
 
+char* Producer::frame_time( mlt_time_format format )
+{
+	return mlt_producer_frame_time( get_producer(), format );
+}
+
 int Producer::set_speed( double speed )
 {
 	return mlt_producer_set_speed( get_producer( ), speed );
