@@ -109,6 +109,18 @@ static int convert_audio( mlt_frame frame, void **audio, mlt_audio_format *forma
 				error = 0;
 				break;
 			}
+			case mlt_audio_u8:
+			{
+				uint8_t *buffer = mlt_pool_alloc( size );
+				uint8_t *p = buffer;
+				int16_t *q = (int16_t*) *audio;
+				int i = samples * channels + 1;
+				while ( --i )
+					*p++ = ( *q++ >> 8 ) + 128;
+				*audio = buffer;
+				error = 0;
+				break;
+			}
 			default:
 				break;
 			}
@@ -171,6 +183,19 @@ static int convert_audio( mlt_frame frame, void **audio, mlt_audio_format *forma
 				error = 0;
 				break;
 			}
+			case mlt_audio_u8:
+			{
+				uint8_t *buffer = mlt_pool_alloc( size );
+				uint8_t *p = buffer;
+				int32_t *q = (int32_t*) *audio;
+				int s, c;
+				for ( s = 0; s < samples; s++ )
+					for ( c = 0; c < channels; c++ )
+						*p++ = ( q[c * samples + s] >> 24 ) + 128;
+				*audio = buffer;
+				error = 0;
+				break;
+			}
 			default:
 				break;
 			}
@@ -241,6 +266,23 @@ static int convert_audio( mlt_frame frame, void **audio, mlt_audio_format *forma
 				error = 0;
 				break;
 			}
+			case mlt_audio_u8:
+			{
+				uint8_t *buffer = mlt_pool_alloc( size );
+				uint8_t *p = buffer;
+				float *q = (float*) *audio;
+				int s, c;
+				for ( s = 0; s < samples; s++ )
+					for ( c = 0; c < channels; c++ )
+					{
+						float f = *( q + c * samples + s );
+						f = f > 1.0 ? 1.0 : f < -1.0 ? -1.0 : f;
+						*p++ = ( 127 * f ) + 128;
+					}
+				*audio = buffer;
+				error = 0;
+				break;
+			}
 			default:
 				break;
 			}
@@ -310,6 +352,18 @@ static int convert_audio( mlt_frame frame, void **audio, mlt_audio_format *forma
 				error = 0;
 				break;
 			}
+			case mlt_audio_u8:
+			{
+				uint8_t *buffer = mlt_pool_alloc( size );
+				uint8_t *p = buffer;
+				int32_t *q = (int32_t*) *audio;
+				int i = samples * channels + 1;
+				while ( --i )
+					*p++ = ( *q++ >> 24 ) + 128;
+				*audio = buffer;
+				error = 0;
+				break;
+			}
 			default:
 				break;
 			}
@@ -389,6 +443,107 @@ static int convert_audio( mlt_frame frame, void **audio, mlt_audio_format *forma
 				error = 0;
 				break;
 			}
+			case mlt_audio_u8:
+			{
+				uint8_t *buffer = mlt_pool_alloc( size );
+				uint8_t *p = buffer;
+				float *q = (float*) *audio;
+				int i = samples * channels + 1;
+				while ( --i )
+				{
+					float f = *q++;
+					f = f > 1.0 ? 1.0 : f < -1.0 ? -1.0 : f;
+					*p++ = ( 127 * f ) + 128;
+				}
+				*audio = buffer;
+				error = 0;
+				break;
+			}
+			default:
+				break;
+			}
+			break;
+		case mlt_audio_u8:
+			switch ( requested_format )
+			{
+			case mlt_audio_s32:
+			{
+				int32_t *buffer = mlt_pool_alloc( size );
+				int32_t *p = buffer;
+				int c;
+				for ( c = 0; c < channels; c++ )
+				{
+					uint8_t *q = (uint8_t*) *audio + c;
+					int i = samples + 1;
+					while ( --i )
+					{
+						*p++ = ( (int32_t) *q - 128 ) << 24;
+						q += channels;
+					}
+				}
+				*audio = buffer;
+				error = 0;
+				break;
+			}
+			case mlt_audio_float:
+			{
+				float *buffer = mlt_pool_alloc( size );
+				float *p = buffer;
+				int c;
+				for ( c = 0; c < channels; c++ )
+				{
+					uint8_t *q = (uint8_t*) *audio + c;
+					int i = samples + 1;
+					while ( --i )
+					{
+						*p++ = ( (float) *q - 128 ) / 256.0f;
+						q += channels;
+					}
+				}
+				*audio = buffer;
+				error = 0;
+				break;
+			}
+			case mlt_audio_s16:
+			{
+				int16_t *buffer = mlt_pool_alloc( size );
+				int16_t *p = buffer;
+				uint8_t *q = (uint8_t*) *audio;
+				int i = samples * channels + 1;
+				while ( --i )
+					*p++ = ( (int16_t) *q++ - 128 ) << 8;
+				*audio = buffer;
+				error = 0;
+				break;
+			}
+			case mlt_audio_s32le:
+			{
+				int32_t *buffer = mlt_pool_alloc( size );
+				int32_t *p = buffer;
+				uint8_t *q = (uint8_t*) *audio;
+				int i = samples * channels + 1;
+				while ( --i )
+					*p++ = ( (int32_t) *q++ - 128 ) << 24;
+				*audio = buffer;
+				error = 0;
+				break;
+			}
+			case mlt_audio_f32le:
+			{
+				float *buffer = mlt_pool_alloc( size );
+				float *p = buffer;
+				uint8_t *q = (uint8_t*) *audio;
+				int i = samples * channels + 1;
+				while ( --i )
+				{
+					float f = ( (float) *q++ - 128 ) / 256.0f;
+					f = f > 1.0 ? 1.0 : f < -1.0 ? -1.0 : f;
+					*p++ = f;
+				}
+				*audio = buffer;
+				error = 0;
+				break;
+			}
 			default:
 				break;
 			}
