@@ -202,6 +202,13 @@ static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format
 	// Reset the aspect ratio
 	mlt_properties_set_double( properties, "aspect_ratio", aspect_ratio );
 
+	// XXX: This is a hack, but it forces the force_full_luma to apply by doing a RGB
+	// conversion because range scaling only occurs on YUV->RGB. And we do it here,
+	// after the deinterlace filter, which only operates in YUV to avoid a YUV->RGB->YUV->?.
+	// Instead, it will go YUV->RGB->?.
+	if ( mlt_properties_get_int( properties, "force_full_luma" ) )
+		*format = mlt_image_rgb24a;
+
 	// Hmmm...
 	char *rescale = mlt_properties_get( properties, "rescale.interp" );
 	if ( rescale != NULL && !strcmp( rescale, "none" ) )
