@@ -19,14 +19,24 @@
  */
 
 #include <string.h>
-
+#include <limits.h>
 #include <framework/mlt.h>
 
 extern mlt_consumer consumer_libdv_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_producer producer_libdv_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 
+static mlt_properties metadata( mlt_service_type type, const char *id, void *data )
+{
+	char file[ PATH_MAX ];
+	snprintf( file, PATH_MAX, "%s/dv/%s", mlt_environment( "MLT_DATA" ), (char*) data );
+	return mlt_properties_parse_yaml( file );
+}
+
 MLT_REPOSITORY
 {
 	MLT_REGISTER( consumer_type, "libdv", consumer_libdv_init );
 	MLT_REGISTER( producer_type, "libdv", producer_libdv_init );
+
+	MLT_REGISTER_METADATA( consumer_type, "libdv", metadata, "consumer_libdv.yml" );
+	MLT_REGISTER_METADATA( producer_type, "libdv", metadata, "producer_libdv.yml" );
 }
