@@ -42,14 +42,17 @@
 
 static RGB32 palette[256];
 
-/* FIXME: endianess? */
 static void makePalette(void)
 {
 	int i, r, g, b;
+	uint8_t *p = (uint8_t*) palette;
 
 	for(i=0; i<MaxColor; i++) {
 		HSItoRGB(4.6-1.5*i/MaxColor, (double)i/MaxColor, (double)i/MaxColor, &r, &g, &b);
-		palette[i] = ((r<<16)|(g<<8)|b) & 0xfefeff;
+		*p++ = r & 0xfe;
+		*p++ = g & 0xfe;
+		*p++ = b & 0xfe;
+		p++;
 	}
 	for(i=MaxColor; i<256; i++) {
 		if(r<255)r++;if(r<255)r++;if(r<255)r++;
@@ -57,7 +60,10 @@ static void makePalette(void)
 		if(g<255)g++;
 		if(b<255)b++;
 		if(b<255)b++;
-		palette[i] = ((r<<16)|(g<<8)|b) & 0xfefeff;
+		*p++ = r & 0xfe;
+		*p++ = g & 0xfe;
+		*p++ = b & 0xfe;
+		p++;
 	}
 }
 
@@ -97,8 +103,9 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 		unsigned char v, w;
 		RGB32 a, b;
 
-		diff = mlt_properties_get_data( MLT_FILTER_PROPERTIES( filter ), 
-						"_diff", NULL );
+		mlt_service_lock( MLT_FILTER_SERVICE( filter ) );
+
+		diff = mlt_properties_get_data( MLT_FILTER_PROPERTIES( filter ), "_diff", NULL );
 		if (diff == NULL)
 		{
 			diff = mlt_pool_alloc(video_area*sizeof(unsigned char));
@@ -106,8 +113,7 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 					diff, video_area*sizeof(unsigned char), mlt_pool_release, NULL );
 		}
 
-		buffer = mlt_properties_get_data( MLT_FILTER_PROPERTIES( filter ), 
-						"_buffer", NULL );
+		buffer = mlt_properties_get_data( MLT_FILTER_PROPERTIES( filter ), "_buffer", NULL );
 		if (buffer == NULL)
 		{
 			buffer = mlt_pool_alloc(video_area*sizeof(unsigned char));
@@ -116,7 +122,6 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 					buffer, video_area*sizeof(unsigned char), mlt_pool_release, NULL );
 		}
 
-
 		if (burn_foreground == 1) {
 			/* to burn the foreground, we need a background */
 			background = mlt_properties_get_data( MLT_FILTER_PROPERTIES( filter ), 
@@ -130,6 +135,8 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 			}
 		}
 
+		mlt_service_unlock( MLT_FILTER_SERVICE( filter ) );
+
 		if (burn_foreground == 1) {
 			image_bgsubtract_y(diff, background, src, video_area, y_threshold);
 		} else {
