@@ -157,6 +157,7 @@ mlt_producer producer_pango_init( const char *filename )
 		mlt_properties_set_int( properties, "seekable", 1 );
 
 		if ( filename == NULL || ( filename && ( !strcmp( filename, "" )
+			|| strstr( filename, "<producer>" )
 			// workaround for old kdenlive countdown generator
 			|| strstr( filename, "&lt;producer&gt;" ) ) ) )
 		{
@@ -168,7 +169,8 @@ mlt_producer producer_pango_init( const char *filename )
 			char *markup = copy;
 			if ( strstr( markup, "/+" ) )
 				markup = strstr( markup, "/+" ) + 2;
-			( *strrchr( markup, '.' ) ) = '\0';
+			if ( strrchr( markup, '.' ) )
+				( *strrchr( markup, '.' ) ) = '\0';
 			while ( strchr( markup, '~' ) )
 				( *strchr( markup, '~' ) ) = '\n';
 			mlt_properties_set( properties, "resource", filename );
@@ -369,14 +371,13 @@ static void refresh_image( mlt_frame frame, int width, int height )
 	if ( pixbuf == NULL )
 	{
 		// Check for file support
-		int position = mlt_properties_get_position( properties, "pango_position" );
 		mlt_properties contents = mlt_properties_get_data( producer_props, "contents", NULL );
 		mlt_geometry key_frames = mlt_properties_get_data( producer_props, "key_frames", NULL );
 		struct mlt_geometry_item_s item;
 		if ( contents != NULL )
 		{
 			char temp[ 20 ];
-			mlt_geometry_prev_key( key_frames, &item, position );
+			mlt_geometry_prev_key( key_frames, &item, mlt_frame_original_position( frame ) );
 			sprintf( temp, "%d", item.frame );
 			markup = mlt_properties_get( contents, temp );
 		}
@@ -553,7 +554,6 @@ static int producer_get_frame( mlt_producer producer, mlt_frame_ptr frame, int i
 
 	// Update timecode on the frame we're creating
 	mlt_frame_set_position( *frame, mlt_producer_position( producer ) );
-	mlt_properties_set_position( properties, "pango_position", mlt_producer_frame( producer ) );
 
 	// Refresh the pango image
 	pthread_mutex_lock( &pango_mutex );
