@@ -240,6 +240,8 @@ static int jack_process( jack_nframes_t frames, void * data )
 		char *dest = jack_port_get_buffer( self->ports[i], frames );
 
 		jack_ringbuffer_read( self->ringbuffers[i], dest, ring_size < jack_size ? ring_size : jack_size );
+		if ( ring_size < jack_size )
+			memset( dest + ring_size, 0, jack_size - ring_size );
 	}
 
 	return error;
@@ -285,9 +287,10 @@ static void initialise_jack_ports( consumer_jack self )
 			if ( !ports )
 				ports = jack_get_ports( self->jack, NULL, NULL, JackPortIsPhysical | JackPortIsInput );
 			if ( ports )
-				strcpy( con_name, ports[i] );
+				strncpy( con_name, ports[i], sizeof( con_name ));
 			else
 				snprintf( con_name, sizeof( con_name ), "system:playback_%d", i + 1);
+			con_name[ sizeof( con_name ) - 1 ] = '\0';
 		}
 		mlt_log_verbose( NULL, "JACK connect %s to %s\n", mlt_name, con_name );
 		jack_connect( self->jack, mlt_name, con_name );
@@ -303,8 +306,10 @@ static int consumer_play_audio( consumer_jack self, mlt_frame frame, int init_au
 	mlt_audio_format afmt = mlt_audio_float;
 
 	// Set the preferred params of the test card signal
+	double speed = mlt_properties_get_double( MLT_FRAME_PROPERTIES(frame), "_speed" );
 	int channels = mlt_properties_get_int( properties, "channels" );
 	int frequency = mlt_properties_get_int( properties, "frequency" );
+	int scrub = mlt_properties_get_int( properties, "scrub_audio" );
 	int samples = mlt_sample_calculator( mlt_properties_get_double( properties, "fps" ), frequency, self->counter++ );
 	float *buffer;
 
@@ -324,12 +329,15 @@ static int consumer_play_audio( consumer_jack self, mlt_frame frame, int init_au
 		init_audio = 0;
 	}
 
-	if ( init_audio == 0 )
+	if ( init_audio == 0 && ( speed == 1.0 || speed == 0.0 ) )
 	{
 		int i;
 		size_t mlt_size = samples * sizeof(float);
 		float volume = mlt_properties_get_double( properties, "volume" );
 
+		if ( !scrub && speed == 0.0 )
+			volume = 0.0;
+
 		if ( volume != 1.0 )
 		{
 			float *p = buffer;
@@ -477,7 +485,10 @@ static void *consumer_thread( void *arg )
 	int64_t playtime = 0;
 	struct timespec tm = { 0, 100000 };
 //	int last_position = -1;
+
+	pthread_mutex_lock( &self->refresh_mutex );
 	self->refresh_count = 0;
+	pthread_mutex_unlock( &self->refresh_mutex );
 
 	// Loop until told not to
 	while( self->running )
