@@ -23,8 +23,9 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE
-
+#endif
 #include <math.h>
 
 #include "plugin_settings.h"
