@@ -65,7 +65,14 @@ FOURCC make_fourcc( const char *s )
 
 
 RIFFDirEntry::RIFFDirEntry()
-{}
+{
+	type = 0;
+	name = 0;
+	length = 0;
+	offset = 0;
+	parent = 0;
+	written = 0;
+}
 
 
 RIFFDirEntry::RIFFDirEntry ( FOURCC t, FOURCC n, int l, int o, int p ) : type( t ), name( n ), length( l ), offset( o ), parent( p ), written( 0 )
@@ -530,11 +537,12 @@ void RIFFFile::ParseRIFF( void )
 {
 	FOURCC type;
 	DWORD length;
-	off_t filesize;
+	off_t filesize = 0;
 	off_t pos;
 	int container = AddDirectoryEntry( make_fourcc( "FILE" ), make_fourcc( "FILE" ), 0, RIFF_NO_PARENT );
 
 	pos = lseek( fd, 0, SEEK_SET );
+	fail_if( pos == -1 );
 
 	/* calculate file size from RIFF header instead from physical file. */
 
