@@ -139,8 +139,8 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 						memcpy (savealpha, alpha , luma_width * luma_height );
 						memcpy (savepic, luma_image , luma_width * luma_height * 2);
 						
-						mlt_properties_set_data ( properties , savename , savepic , sizeof(uint8_t*) , mlt_pool_release, NULL );
-						mlt_properties_set_data ( properties , savename1 , savealpha , sizeof(uint8_t*)  ,  mlt_pool_release, NULL );
+						mlt_properties_set_data ( properties , savename , savepic , sizeof(savepic) , mlt_pool_release, NULL );
+						mlt_properties_set_data ( properties , savename1 , savealpha , sizeof(savealpha)  ,  mlt_pool_release, NULL );
 						mlt_properties_set_int ( properties , cachedy , luma_height );
 						
 						overlay_image(*image,*width,*height,luma_image,luma_width,luma_height, alpha, x1, y1 , updown , mirror );
@@ -163,9 +163,6 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 
 		int h = *height;
 		int w = *width;
-		if (maxcount==0)
-			return 0;
-
 		int im=rand()%maxcount;
 		
 		while (im-- ){
