@@ -27,20 +27,24 @@
 #include <qimage.h>
 #include <qmutex.h>
 
-#ifdef USE_KDE
+#ifdef USE_KDE3
 #include <kinstance.h>
 #include <kimageio.h>
 #endif
-
 #endif
 
+#ifdef USE_KDE4
+#include <kcomponentdata.h>
+#endif
 
 #ifdef USE_QT4
 #include <QtGui/QImage>
 #include <QtCore/QSysInfo>
+#include <QtGui/QApplication>
 #include <QtCore/QMutex>
 #include <QtCore/QtEndian>
 #include <QtCore/QTemporaryFile>
+#include <QtCore/QLocale>
 #endif
 
 #ifdef USE_EXIF
@@ -55,30 +59,40 @@ extern "C" {
 #include <framework/mlt_pool.h>
 #include <framework/mlt_cache.h>
 
-#ifdef USE_KDE
+#ifdef USE_KDE4
+static KComponentData *instance = 0L;
+#elif USE_KDE3
 static KInstance *instance = 0L;
 #endif
 
+static QApplication *app = NULL;
+
 static void qimage_delete( void *data )
 {
 	QImage *image = ( QImage * )data;
 	delete image;
 	image = NULL;
-#ifdef USE_KDE
+#if defined(USE_KDE3) || defined(USE_KDE4) 
 	if (instance) delete instance;
 	instance = 0L;
 #endif
+
 }
 
-#ifdef USE_KDE
 void init_qimage()
 {
-	if (!instance) {
-	    instance = new KInstance("qimage_prod");
+#ifdef USE_KDE4
+	if ( !instance ) {
+	    instance = new KComponentData( "qimage_prod" );
+	}
+#elif defined(USE_KDE3)
+	if ( !instance ) {
+	    instance = new KInstance( "qimage_prod" );
 	    KImageIO::registerFormats();
 	}
-}
 #endif
+  
+}
 
 static QImage* reorient_with_exif( producer_qimage self, int image_idx, QImage *qimage )
 {
@@ -157,7 +171,7 @@ int refresh_qimage( producer_qimage self, mlt_frame frame )
 	double ttl = mlt_properties_get_int( producer_props, "ttl" );
 
 	// Get the original position of this frame
-	mlt_position position = mlt_properties_get_position( properties, "qimage_position" );
+	mlt_position position = mlt_frame_original_position( frame );
 	position += mlt_producer_get_in( producer );
 
 	// Image index
@@ -168,13 +182,38 @@ int refresh_qimage( producer_qimage self, mlt_frame frame )
 	sprintf( image_key, "%d", image_idx );
 
 	int disable_exif = mlt_properties_get_int( producer_props, "disable_exif" );
+	
+	
+	if ( app == NULL ) 
+	{
+		if ( qApp ) 
+		{
+			app = qApp;
+		}
+		else 
+		{
+#ifdef linux
+			if ( getenv("DISPLAY") == 0 )
+			{
+				mlt_log_panic( MLT_PRODUCER_SERVICE( producer ), "Error, cannot render titles without an X11 environment.\nPlease either run melt from an X session or use a fake X server like xvfb:\nxvfb-run -a melt (...)\n" );
+				return -1;
+			}
+#endif
+			int argc = 1;
+			char* argv[1];
+			argv[0] = (char*) "xxx";
+			app = new QApplication( argc, argv );
+			const char *localename = mlt_properties_get_lcnumeric( MLT_SERVICE_PROPERTIES( MLT_PRODUCER_SERVICE( producer ) ) );
+			QLocale::setDefault( QLocale( localename ) );
+		}
+	}
 
 	if ( image_idx != self->qimage_idx )
 		self->qimage = NULL;
 	if ( !self->qimage || mlt_properties_get_int( producer_props, "_disable_exif" ) != disable_exif )
 	{
 		self->current_image = NULL;
-		QImage *qimage = new QImage( mlt_properties_get_value( self->filenames, image_idx ) );
+		QImage *qimage = new QImage( QString::fromUtf8( mlt_properties_get_value( self->filenames, image_idx ) ) );
 		self->qimage = qimage;
 
 		if ( !qimage->isNull( ) )
